@@ -22,7 +22,7 @@
 #ifndef __GOK_MODIFIER_KEYMASKS_H__
 #define __GOK_MODIFIER_KEYMASKS_H__
 
-#include <gnome.h>
+#include <glib.h>
 
 struct gok_modifier_keymask {
 	gchar *name;
